@@ -42,7 +42,7 @@ unzip(paste0(p_dir, "/gps_files.zip"), exdir = paste0(p_dir, "/gpx"))
 remove(url)
 
 # Save GPS files with participant movement as dataframe
-tracks <- dir_get_gpx(paste0(p_dir, "/gpx"), stringsAsFactors = FALSE)
+tracks <- dir_get_gpx(paste0(p_dir, "/gpx"))
 
 # The experiment took place between 13:45 and 14:55. Therefore we select this
 # data.
@@ -65,7 +65,7 @@ rm(list = setdiff(ls(), "p_dir"))
 load(paste0(p_dir, "/rdata/01.RData"))
 
 tracks <- dir_add_csv(
-  tracks, paste0(p_dir, "/gpx/ids.csv"), stringsAsFactors = FALSE
+  tracks, paste0(p_dir, "/gpx/ids.csv")
 )
 
 # Get first descriptives
