@@ -5,7 +5,7 @@ rm(list = ls())
 data(psyo)
 csv_dir <- system.file("extdata", "ids.csv", package = "psyosphere")
 
-# Check with default stringsAsFactors ------------------------------------------
+# Check ------------------------------------------------------------------------
 
 # Calculations
 
@@ -17,10 +17,10 @@ if (NROW(psyo_csv) != 15) { stop("Not rows") }
 e <- val_psyo(psyo_csv); if (e != "") {stop(e)}
 rm(psyo_csv, e)
 
-# Check with default stringsAsFactors FALSE ------------------------------------
+# Check class ------------------------------------------------------------------
 
 # Calculations
-psyo_csv <- dir_add_csv(psyo, csv_dir, stringsAsFactors = FALSE)
+psyo_csv <- dir_add_csv(psyo, csv_dir)
 
 # Check results
 if (class(psyo_csv[,"team"]) != "character") { stop("Wrong class") }
