@@ -5,7 +5,7 @@ rm(list = ls(all.names = TRUE))
 
 gpx_dir <- system.file("extdata", package="psyosphere")
 
-# Check with default string as factors -----------------------------------------
+# Check ------------------------------------------------------------------------
 
 # Calculations
 psyo_rounds <- dir_get_gpx(gpx_dir, tz="MET")
@@ -18,10 +18,10 @@ test_sum <- sum(psyo_rounds[,"lon"])
 if(round(test_sum,3)!=round(62670.9175,3)) {stop("Wrong test_sum")}
 rm(psyo_rounds)
 
-# Check with strings as factors FALSE ------------------------------------------
+# Check class ------------------------------------------------------------------
 
 # Calculations
-psyo_rounds <- dir_get_gpx(gpx_dir, tz="MET", stringsAsFactors = FALSE)
+psyo_rounds <- dir_get_gpx(gpx_dir, tz="MET")
 
 # Check results
 if (class(psyo_rounds[,"id"]) != "character") {stop("Wrong class")}
